@@ -64,15 +64,33 @@ public:
 	enum QueryType { Reference = 0, Definition = 1, Called = 2, Calling = 3,
 		Text = 4, Pattern = 6, FileName = 7, Including = 8, None = 9 };
 
+	/**
+	 * Options for running Cscope, used to construct the command line.
+	 * Some of these options are global, while some are project specific.
+	 */
+	enum Options { VerboseOut = 0x01, SlowPathDef = 0x02,
+		Kernel = 0x04, InvIndex = 0x08, NoCompression = 0x10 };
+
 	void query(uint, const QString&, uint nMaxRecords = 0);
 	void rebuild();
 	
-	static void init(const QString&, const QStringList&);
-	static bool verify(const QString&);
+	static void init(const QString&, uint);
+	
+	/**
+	 * @param	nArgs	The command-line arguments supported by the version of
+	 *					Cscope currently in use
+	 */
+	static void setSupArgs(uint nArgs) { s_nSupArgs = nArgs; }
 	
 public slots:
 	void slotCancel();
 
+signals:
+	/**
+	 * Emitted when Cscope starts building the inverted index.
+	 */
+	void buildInvIndex();
+
 protected:
 	virtual ParseResult parseStdout(QString&, ParserDelim);
 	virtual void parseStderr(const QString&);
@@ -91,12 +109,6 @@ private:
 	/** Accumulates text sent by Cscope to the standard error stream. */
 	QString m_sErrMsg;
 	
-	/** The full path of the directory holding the project files. */
-	static QString s_sProjPath;
-	
-	/** Project-specific command-line arguments to pass to Cscope. */
-	static QStringList s_slProjArgs;
-	
 	/** If true, the rebuild process will be restarted when the process
 		exits. */
 	bool m_bRebuildOnExit;
@@ -105,6 +117,15 @@ private:
 		The process aborts if this number if reached. */
 	int m_nMaxRecords;
 	
+	/** The full path of the directory holding the project files. */
+	static QString s_sProjPath;
+	
+	/** Project-specific options for the command-line arguments. */
+	static uint s_nProjArgs;
+	
+	/** The command line arguments supported by this version of Cscope. */
+	static uint s_nSupArgs;
+	
 	bool run(const QStringList&);
 };
 
@@ -141,4 +162,25 @@ private slots:
 	void slotShowLabel();
 };
 
+class CscopeVerifier : public QObject
+{
+	Q_OBJECT
+	
+public:
+	CscopeVerifier() : m_bResult(false), m_nArgs(0) {}
+	
+	void verify();
+	
+signals:
+	void done(bool, uint);
+	
+private:
+	bool m_bResult;
+	uint m_nArgs;
+	
+private slots:
+	void slotConfigResult(uint, const QString&);
+	void slotFinished();
+};
+
 #endif
