@@ -64,6 +64,18 @@ bool CtagsFrontend::run(const QString& sFileName)
 	slArgs.append("-u"); // don't sort
 	slArgs.append("-f");
 	slArgs.append("-");
+	
+	// The following regular expressions add support for goto labels and file
+	// inclusions.
+	// NOTE: We need to add the 'include' pattern to C++, since .h files are
+	// treated as C++ rather than C. This also allows KScope some limited C++
+	// support.
+	slArgs.append("--regex-c=/^[ \\t]*([_a-zA-Z][_a-zA-Z0-9]*):/\\1/l,label/");
+	slArgs.append("--regex-c=/^[ \\t]*#[ \\t]*include[ \\t]*[\\\"<]"
+		"([_a-zA-Z0-9\\.\\/]*)[\\\">]/\\1/i,include/");
+	slArgs.append("--regex-c++=/^[ \\t]*#[ \\t]*include[ \\t]*[\\\"<]"
+		"([_a-zA-Z0-9\\.\\/]*)[\\\">]/\\1/i,include/");
+	
 	slArgs.append(sFileName);
 
 	// Run a new process
