@@ -95,6 +95,8 @@ void DirScanner::run()
 	nFiles = scanDir(m_dir);
 	QApplication::postEvent(m_pEventReceiver,
 		new DirScanEvent(nFiles, true));
+	
+	m_setScanned.clear();
 }
 
 /**
@@ -105,6 +107,7 @@ void DirScanner::run()
  */
 int DirScanner::scanDir(QDir& dir)
 {
+	QString sCanon;
 	QStringList slDirFiles, slDirs;
 	QStringList::const_iterator itr;
 	QString sFile;
@@ -113,6 +116,14 @@ int DirScanner::scanDir(QDir& dir)
 	if (m_bCancel)
 		return -1;
 		
+	// Make sure this directory has not been previously visited (e.g., through a
+	// symbolic link)
+	sCanon = dir.canonicalPath();
+	if (m_setScanned.exists(sCanon))
+		return 0;
+	
+	m_setScanned.insert(sCanon);
+	
 	// Add all files in this directory
 	slDirFiles = dir.entryList(m_sNameFilter, QDir::Files);
 	for (itr = slDirFiles.begin(); itr != slDirFiles.end(); ++itr) {
