@@ -64,24 +64,15 @@ signals:
 	 * @param	nLine	Line number, always set to 0
 	 */
 	void fileRequested(const QString& sPath, uint nLine);
-	
-	/**
-	 * Emitted when a new root directory is set for the file tree.
-	 * @param	sPath	The full path of the new root directory
-	 */
-	void rootChanged(const QString& sPath);
-	
-	/**
-	 * Emitted when the "Find..." button of the widget is clicked.
-	 */
-	void findFile();
 
 private:
 	/** The current branch in the file tree. */
 	KFileTreeBranch* m_pCurBranch;
 
+	/** The current root of the file tree. */
+	QString m_sRoot;
+	
 private slots:
-	void slotChangeRoot();
 	void slotTreeItemSelected(QListViewItem*);
 };
 
