@@ -31,12 +31,14 @@
 #include <qpainter.h>
 #include <qtooltip.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 #include "graphwidget.h"
 #include "graphnode.h"
 #include "graphedge.h"
 #include "kscopeconfig.h"
 #include "queryviewdlg.h"
 #include "encoder.h"
+#include "progressdlg.h"
 
 const char* GRAPH_DIRS[] = { "TB", "LR", "BT", "RL" };
 
@@ -120,7 +122,9 @@ GraphWidget::GraphWidget(QWidget* pParent, const char* szName) :
 	m_progress(this),
 	m_dot(this),
 	m_dZoom(1.0),
-	m_nMaxNodeDegree(10) // will be overriden by CallTreeDlg
+	m_nMaxNodeDegree(10), // will be overriden by CallTreeDlg
+	m_nMultiCallNum(0),
+	m_pProgressDlg(NULL)					 
 {
 	// Automatically delete nodes when they are removed
 	m_dictNodes.setAutoDelete(true);
@@ -149,7 +153,7 @@ GraphWidget::GraphWidget(QWidget* pParent, const char* szName) :
 		SLOT(slotAborted()));
 	
 	// Redraw the graph when Dot exits
-	connect(&m_dot, SIGNAL(finished(uint)), this, SLOT(slotRepaint()));	
+	connect(&m_dot, SIGNAL(finished(uint)), this, SLOT(slotDotFinished()));	
 	
 	// Create the node popup menu
 	m_pNodePopup = new QPopupMenu(this);
@@ -219,14 +223,14 @@ void GraphWidget::setRoot(const QString& sFunc)
  * @param	sFunc	The name of a function
  * @return	The node corresponding to the given name
  */
-GraphNode* GraphWidget::addNode(const QString& sFunc)
+GraphNode* GraphWidget::addNode(const QString& sFunc, bool bMultiCall)
 {
 	GraphNode* pNode;
 	
 	// Look for a node with the given name
 	if ((pNode = m_dictNodes.find(sFunc)) == NULL) {
 		// Node not found, create it
-		pNode = new GraphNode(canvas(), sFunc);
+		pNode = new GraphNode(canvas(), sFunc, bMultiCall);
 		m_dictNodes.insert(sFunc, pNode);
 	}
 	
@@ -263,32 +267,31 @@ void GraphWidget::addCall(const CallData& data)
  * @param	bCalled	true if the multiple calls are called from that function,
  *					false if they are calling the function
  */
-void GraphWidget::addMultiCall(const QString& /*sFunc*/, bool /*bCalled*/)
+void GraphWidget::addMultiCall(const QString& sFunc, bool bCalled)
 {
-/*	QString sMulti;
-	Agnode_t* pFunc, * pMulti;
+	QString sMulti;
+	GraphNode* pCaller, * pCallee;
+	GraphEdge* pEdge;
 	
 	// Create a unique name for the new node.
-	sMulti = sFunc + "$MULTI_" + (bCalled ? "CALLED" : "CALLING");
+	// The name is of the form 0XXX, where XXX is a hexadecimal number. 
+	// We assume that no function starts with a digit, and that there are no
+	// more than 0xfff multi-call nodes in the graph.
+	sMulti.sprintf("0%.3x", m_nMultiCallNum);
+	m_nMultiCallNum = (m_nMultiCallNum + 1) & 0xfff;
 	
 	// Find the relevant nodes (create new nodes if necessary)
-	pFunc = agnode(m_pGraph, (char*)sFunc.latin1());
-	pMulti = agnode(m_pGraph, (char*)sMulti.latin1());
+	if (bCalled) {
+		pCaller = addNode(sFunc);
+		pCallee = addNode(sMulti, true);
+	}
+	else {
+		pCaller = addNode(sMulti, true);
+		pCallee = addNode(sFunc);
+	}
 	
-	// Set properties of the new node
-	SET_NODE_ATTR(pMulti, "label", "...");
-	SET_NODE_ATTR(pMulti, "fillcolor",
-		Config().getColor(KScopeConfig::GraphMultiCall).name().latin1());
-	SET_NODE_ATTR(pMulti, "kscope_multi", ATTR_TRUE);
-	SET_NODE_ATTR(pMulti, "kscope_multi_parent", sFunc.latin1());
-	SET_NODE_ATTR(pMulti, "kscope_multi_called", 
-		bCalled ? ATTR_TRUE : ATTR_FALSE);
-	
-	// Create a directed edge
-	if (bCalled)
-		agedge(m_pGraph, pFunc, pMulti);
-	else	
-		agedge(m_pGraph, pMulti, pFunc);*/
+	// Create a new edge
+	pEdge = pCaller->addOutEdge(pCallee);
 }
 
 /**
@@ -303,6 +306,10 @@ void GraphWidget::draw()
 	int nFd;
 	FILE* pFile;
 	
+	// Do nothing if drawing process has already started
+	if (m_dot.isRunning())
+		return;
+	
 	// Apply the zoom factor
 	mtx.scale(m_dZoom, m_dZoom);
 	setWorldMatrix(mtx);
@@ -316,7 +323,10 @@ void GraphWidget::draw()
 	if ((pFile = fdopen(nFd, "w")) == NULL)
 		return;
 	
-	// Write the graph contrents to the temporary file
+	// Remember the file name (so it can be deleted later)
+	m_sDrawFilePath = szTempFile;
+	
+	// Write the graph contents to the temporary file
 	{
 		QTextStream str(pFile, IO_WriteOnly);
 		write(str, "graph", "--", false);
@@ -326,7 +336,19 @@ void GraphWidget::draw()
 	fclose(pFile);
 	
 	// Draw the graph
-	m_dot.run(szTempFile);
+	if (m_dot.run(szTempFile)) {
+		// Create the progress dialogue
+		m_pProgressDlg = new ProgressDlg(i18n("KScope"), 
+			i18n("Generating graph, please wait"), this);
+		m_pProgressDlg->setMinimumDuration(1000);
+		m_pProgressDlg->setValue(0);
+		
+		// TODO:
+		// Implement cancel (what do we do when the drawing process is 
+		// terminated, even though the nodes and edges were already added by
+		// Cscope?)
+		// m_pProgressDlg->setAllowCancel(true);
+	}
 }
 
 /**
@@ -483,9 +505,13 @@ void GraphWidget::drawNode(const QString& sFunc, const QRect& rect)
 	pNode->setRect(rect);
 	pNode->setZ(2.0);
 	pNode->setPen(QPen(Qt::black));
-	pNode->setBrush(Config().getColor(KScopeConfig::GraphNode));
 	pNode->setFont(Config().getFont(KScopeConfig::Graph));
 	
+	if (pNode->isMultiCall())
+		pNode->setBrush(Config().getColor(KScopeConfig::GraphMultiCall));
+	else
+		pNode->setBrush(Config().getColor(KScopeConfig::GraphNode));
+	
 	// Draw the node
 	pNode->show();
 }
@@ -642,7 +668,7 @@ void GraphWidget::write(QTextStream& str, const QString& sType,
 	
 	// Graph attributes
 	str << "\tgraph [rankdir=" << Config().getGraphOrientation() << ", "
-		<< "kscope_zoom=" << m_dZoom
+		<< "kscope_zoom=" << m_dZoom 
 		<< "];\n";
 	
 	// Default node attributes
@@ -766,8 +792,20 @@ void GraphWidget::showEdgeMenu(GraphEdge* pEdge, const QPoint& ptPos)
  * This slot is connected to the finished() signal emitted by the dot front-
  * end.
  */
-void GraphWidget::slotRepaint()
+void GraphWidget::slotDotFinished()
 {
+	// Delete the temporary file
+	if (m_sDrawFilePath != "") {
+		QFile::remove(m_sDrawFilePath);
+		m_sDrawFilePath = "";
+	}
+	
+	// Delete the progress dialogue
+	if (m_pProgressDlg) {
+		delete m_pProgressDlg;
+		m_pProgressDlg = NULL;
+	}
+	
 	setUpdatesEnabled(true);
 	canvas()->update();
 }
@@ -847,8 +885,14 @@ void GraphWidget::slotFinished(uint /*nRecords*/)
  * This slot is attached to the aborted() signal of the Cscope process.
  */
 void GraphWidget::slotAborted()
-{
+{	
+	KMessageBox::information(this, i18n("The query produced too many results.\n"
+		"A multiple-call node will appear in the graph instead.\n"
+		"Hint: The maximum number of in/out edges\n"
+		"can be adjusted by clicking the dialogue's \"Preferences\" button"));
+	
 	addMultiCall(m_sQueriedFunc, m_bCalled);
+	draw();
 }
 
 /**
@@ -1079,24 +1123,24 @@ void GraphWidget::slotRemoveNode()
  */
 void GraphWidget::slotMultiCallDetails()
 {
-/*	GraphNode* pNode;
-	QString sFunc;
-	uint nType;
+	GraphNode* pNode, * pParent;
+	bool bCalled;
 	
 	// Make sure the menu item is a node
 	pNode = dynamic_cast<GraphNode*>(m_pMenuItem);
-	if (pNode == NULL)
+	if (pNode == NULL || !pNode->isMultiCall())
 		return;
 	
 	// Get the required information from the node
-	sFunc = GET_NODE_ATTR(pNode->getNode(), "kscope_multi_parent");
-	nType = IS_TRUE(GET_NODE_ATTR(pNode->getNode(), "kscope_multi_called")) ?
-		CscopeFrontend::Called : CscopeFrontend::Calling;
+	pNode->getFirstNeighbour(pParent, bCalled);
+	if (!pParent)
+		return;
 		
 	QueryViewDlg dlg(0, (QWidget*)parent());
 	
-	dlg.query(nType, sFunc);
-	dlg.exec();*/
+	dlg.query(bCalled ? CscopeFrontend::Calling : CscopeFrontend::Called, 
+		pParent->getFunc());
+	dlg.exec();
 }
 
 /**
@@ -1111,7 +1155,7 @@ void GraphWidget::slotOpenCall()
 	
 	// Make sure the menu item is an edge
 	pEdge = dynamic_cast<GraphEdge*>(m_pMenuItem);
-	if (pEdge != NULL)
+	if (pEdge != NULL && pEdge->getFile() != "")
 		emit lineRequested(pEdge->getFile(), pEdge->getLine());
 }
 
