@@ -674,6 +674,7 @@ void KScope::slotQuery(uint nType, bool bPrompt)
  */
 void KScope::openProject(const QString& sDir)
 {
+	QString sProjDir;
 	ProjectBase* pProj;
 	QStringList slQueryFiles;
 	QStringList slCallTreeFiles;
@@ -686,7 +687,8 @@ void KScope::openProject(const QString& sDir)
 		return;
 
 	// Open the project in the project manager
-	if (!m_pProjMgr->open(sDir))
+	sProjDir = QDir::cleanDirPath(sDir);
+	if (!m_pProjMgr->open(sProjDir))
 		return;
 	
 	// Change main window title
@@ -1047,6 +1049,9 @@ bool KScope::slotCloseProject()
 	// Reset queried symbols history
 	SymbolDlg::resetHistory();
 	
+    // Remove any remaining status bar messages
+    statusBar()->message("");
+    
 	return true;
 }
 
