@@ -29,14 +29,19 @@
 
 /**
  * Class constructor.
- * @param	pParent	The parent widget
- * @param	szName	The widget's name
+ * @param	sCaption	The dialogue's title
+ * @param	sText		The text to display
+ * @param	pParent		The parent widget
+ * @param	szName		The widget's name
  */
 ProgressDlg::ProgressDlg(const QString& sCaption, const QString& sText,
 	QWidget* pParent, const char* szName) :
 	KProgressDialog(pParent, szName, sCaption, sText, true),
 	m_nIdleValue(-1)
 {
+	setAutoClose(false);
+	setAllowCancel(false);
+	
 	// Create the idle-progress timer
 	m_pIdleTimer = new QTimer(this);
 
@@ -87,6 +92,12 @@ void ProgressDlg::setValue(int nValue)
 	}
 }
 
+void ProgressDlg::setIdle()
+{
+	m_nIdleValue = -1;
+	setValue(0);
+}
+
 /**
  * Increaes the value of the dummy counter by 1.
  * This slot is called by the timeout() event of the idle timer.
