@@ -31,7 +31,7 @@
 #include <qwidget.h>
 #include <projectfileslayout.h>
 #include <qdict.h>
-#include "projectmanager.h"
+#include "project.h"
 
 class DirScanner;
 class ScanProgressDlg;
@@ -56,8 +56,7 @@ class ProjectFilesDlg : public ProjectFilesLayout, public FileListTarget,
    Q_OBJECT
 
 public: 
-	ProjectFilesDlg(ProjectManager*, QWidget* pParent = 0,
-		const char* szName = 0);
+	ProjectFilesDlg(Project*, QWidget* pParent = 0,	const char* szName = 0);
 	~ProjectFilesDlg();
 
 	virtual void addItem(const QString&);
@@ -68,8 +67,8 @@ protected:
 	virtual void customEvent(QCustomEvent*);
 
 private:
-	/** Points to the project manager object created by the KScope class. */
-	ProjectManager* m_pProjMgr;
+	/** The project to manipulate. */
+	Project* m_pProj;
 
 	/** Holds all file paths in a quickly searchable format (for duplicate
 		entries lookup). */
