@@ -44,7 +44,6 @@ QueryWidget::QueryWidget(QWidget* pParent, const char* szName) :
 	m_pLockAction(NULL),
 	m_pHistPage(NULL),
 	m_bHistEnabled(true),
-	m_pBMarkPage(NULL),
 	m_nQueryPages(0)
 {
 	// Pages can be closed by clicking their tabs
@@ -350,7 +349,6 @@ void QueryWidget::slotCloseAll()
 	}
 	
 	m_pHistPage = NULL;
-	m_pBMarkPage = NULL;
 }
 
 /**
@@ -379,53 +377,6 @@ void QueryWidget::slotHistoryNext()
 	}
 }
 
-/**
- * Called when a bookmark is added or removed on an editor page.
- * Updates the active bookmarks page.
- * This slot is connected to the bookmarkChanged() signal of each EditorPage
- * object.
- * @param	sPath	The file for which a bookmark was changed
- * @param	nLine	The bookmark's line number
- * @param	sText	The line's contents
- * @param	bAdded	True if a bookmark was added, false if it was removed
- */
-void QueryWidget::slotBookmarkChanged(const QString& sPath, uint nLine,
-	const QString& sText, bool bAdded)
-{
-	// Get the active bookmark page (add one if necessary)
-	findBookmarkPage();
-	
-	// Add or remove the bookmark, as required
-	if (bAdded)
-		m_pBMarkPage->addRecord(sPath, nLine, sText);
-	else
-		m_pBMarkPage->removeRecord(sPath, nLine);
-}
-
-/**
- * Deletes all bookmarks for the given file.
- * This slot is connected to the fileClosed() signal emitted by an EditorPage.
- * @param	sPath	The path of the file for which bookmarks should be removed
- */
-void QueryWidget::slotRemoveBookmarks(const QString& sPath)
-{
-	// Don't use findBookmarkPage(), since we don't want to show this page if
-	// it is currently hidden. All we care about is whether the page exists
-	if (m_pBMarkPage)
-		m_pBMarkPage->removeFile(sPath);
-}
-
-/**
- * Handles the "Bookmarks->Browse Global Bookmarks" menu command.
- * Sets the keyboard focus to the bookmarks page.
- */
-void QueryWidget::slotBrowseBookmarks()
-{
-	findBookmarkPage();
-	setCurrentPage(m_pBMarkPage);
-	m_pBMarkPage->setFocus();
-}
-
 /**
  * Sets the active history page, if any, as the current page.
  */
@@ -448,18 +399,6 @@ void QueryWidget::setPageMenu(QPopupMenu* pMenu, KToggleAction* pAction)
 	m_pLockAction = pAction;
 }
 
-/**
- * Fills a list with the locations of all defined bookmarks.
- * @param	list	The list to fill
- */
-void QueryWidget::getBookmarks(FileLocationList& list)
-{
-	if (!m_pBMarkPage)
-		return;
-		
-	m_pBMarkPage->fillList(list);
-}
-
 /**
  * Emits a signal indicating a certain source file and line number are
  * requested.
@@ -502,13 +441,6 @@ void QueryWidget::slotCurrentChanged(QWidget* pWidget)
  */
 void QueryWidget::slotClosePage(QWidget* pPage)
 {
-	// The bookmarks page is only hidden, not deleted (so that bookmarks are
-	// not lost)
-	if (pPage == m_pBMarkPage) {
-		m_pQueryTabs->removePage(pPage);
-		return;
-	}
-	
 	// Prompt the user before closing a locked query
 	if (((QueryPage*)pPage)->isLocked()) {
 		if (KMessageBox::questionYesNo(NULL, i18n("You about about to close"
@@ -674,30 +606,4 @@ void QueryWidget::findHistoryPage()
 		SLOT(slotRequestLine(const QString&, uint)));
 }
 
-/**
- * Ensures an active bookmarks page exists.
- * There is at most one bookmarks page. If such a page does not already exist, 
- * one is created.
- */
-void QueryWidget::findBookmarkPage()
-{
-	QString sTitle;
-	
-	// Create a new page, if one does not already exist
-	if (!m_pBMarkPage) {
-		m_pBMarkPage = new BookmarkPage(this);
-		
-		// Emit the lineRequested() signal when a query record is selected on 
-		// this page
-		connect(m_pBMarkPage, SIGNAL(lineRequested(const QString&, uint)), this, 
-			SLOT(slotRequestLine(const QString&, uint)));
-	}
-
-	if (m_pQueryTabs->indexOf(m_pBMarkPage) == -1) {
-		// Add the page, and set it as the current one
-		m_pQueryTabs->insertTab(m_pBMarkPage, GET_PIXMAP(TabBookmark), "");
-		setPageCaption(m_pBMarkPage);
-	}
-}
-
 #include "querywidget.moc"
