@@ -29,11 +29,11 @@
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qradiobutton.h>
-#include <qcheckbox.h>
 #include "searchresultsdlg.h"
 
 int SearchResultsDlg::s_nType = PlainText;
 bool SearchResultsDlg::s_bCaseSensitive = true;
+bool SearchResultsDlg::s_bNegate = false;
 
 /**
  * Class constructor.
@@ -58,9 +58,10 @@ SearchResultsDlg::SearchResultsDlg(QWidget* pParent, const char* szName) :
 		break;
 	}
 
-	// Set the default value of the "Case Sensitive" check-box
+	// Set the default value of the check-boxes
 	m_pCaseSenCheck->setChecked(s_bCaseSensitive);
-	
+	m_pNegateCheck->setChecked(s_bNegate);
+		
 	// Terminate the dialogue when either the "OK" or "Cancel" buttons are
 	// clicked
 	connect(m_pOKButton, SIGNAL(clicked()), this, SLOT(accept()));
@@ -139,9 +140,10 @@ void SearchResultsDlg::accept()
 	else if (m_pSimpRegExpRadio->isChecked())
 		s_nType = SimpRegExp;
 	
-	// Determine whether case-sensitive search is required
+	// Determine search parameters
 	s_bCaseSensitive = m_pCaseSenCheck->isChecked();
-		
+	s_bNegate = m_pNegateCheck->isChecked();
+	
 	// Remove white space from the search text
 	sText = m_pSearchEdit->text();
 	sText.stripWhiteSpace();
