@@ -98,10 +98,23 @@ private:
 	class Entry : public KTextEditor::CompletionEntry
 	{
 	public:
-		bool operator < (const SymbolCompletion::Entry& entry) const 
-			{ return (text < entry.text); }
-		bool operator == (const SymbolCompletion::Entry& entry) const
-			{ return (text == entry.text); }
+		/**
+		 * Determines whether a given entry is smaller than this one.
+		 * @param	entry	The entry to compare with
+		 * @return	true if the given entry is smaller, false otherwise
+		 */
+		bool operator < (const SymbolCompletion::Entry& entry) const {
+			return (text < entry.text);
+		}
+			
+		/**
+		 * Determines whether a given entry is equal to this one.
+		 * @param	entry	The entry to compare with
+		 * @return	true if the given entry equals this one, false otherwise
+		 */
+		bool operator == (const SymbolCompletion::Entry& entry) const {
+			return (text == entry.text);
+		}
 	};
 	
 	/**
